#include <QtGui/QApplication>
#include <QtGui/QGraphicsObject>
#include "examplewidget.h"
char a = 'c';
char * b = &a;
char ** c = &b;
     QDialGPS app(0, c);

QDialGPS::QDialGPS(int argc, char** argv) :  QApplication(argc, argv)
 {
 qDebug("constructor started");
angle = 99;
x=1;
y=2;
z=11111111;
goalx=1111;
goaly=1111;
goalz=11111111;
setCon(false);
 qDebug("constructor ended");
}
static void changed(LocationGPSDevice *device, gpointer pointer)
{
 qDebug("changed");
app.setCx(device->fix->latitude);
app.setCy(device->fix->longitude);
if(device->fix->altitude)
 {
  app.setCz(device->fix->altitude);
 }
if(app.gx()==1111)
 {
   app.setGx(app.cx());
 }
if(app.gy()==1111)
 {
   app.setGy(app.cy());
 }
if(app.gz()==11111111)
 {
      app.setGz(app.cz());
 }
 app.setPangle(QGeoCoordinate(app.cx(),app.cy()).azimuthTo(QGeoCoordinate (app.gx(),app.gy())));
 app.setDist(0);
 app.setAlti(0);
 qDebug("applied");
}
 
static void connected(LocationGPSDevice *device, gpointer pointer)
{
    qDebug("connection starting");
    app.setCon(true);
    qDebug("connection started");
}
 
static void disconnected(LocationGPSDevice *device, gpointer pointer)
{
    qDebug("connection ending");
    app.setCon(false);
    qDebug("connection ended");
}
void QDialGPS::regoal()
{
 qDebug("regoaling");
if(x!=1111)
{
    setGx(x);
}
if(y!=1111)
{
    setGy(y);
}
if(z!=11111111)
{
    setGz(z);
}
 qDebug("regoaled");
}
 int main(int argc, char *argv[])
 {
//     app=QDialGPS::QDialGPS(argc, argv);
     QDeclarativeView view;
    LocationGPSDevice *device;
    LocationGPSDControl *control;
    g_type_init ();
    control = location_gpsd_control_get_default();
    if (control)
        location_gpsd_control_start(control);
 
    device = (LocationGPSDevice*)g_object_new(LOCATION_TYPE_GPS_DEVICE, NULL);
    if (device) {
        g_signal_connect(device, "changed", G_CALLBACK(changed), 0);
        g_signal_connect(device, "connected", G_CALLBACK(connected), 0);
        g_signal_connect(device, "disconnected", G_CALLBACK(disconnected), 0);
    }

    view.rootContext()->setContextProperty("qlgps", &app);
     view.setSource(QUrl("/opt/usr/bin/qtdialgps/ui.qml"));
     view.setResizeMode(QDeclarativeView::SizeRootObjectToView);

     qDebug("connected?");
      #if defined(Q_WS_S60) || defined(Q_WS_MAEMO)
        view.showMaximized();
     #else
       view.setGeometry(100, 100, 800, 480);
       view.show();
     #endif
qDebug("view shown");

    int ret = app.exec();
 
    if (device)
        g_object_unref(device);
    if (control)
        location_gpsd_control_stop(control);
delete &app;
    return ret;
 }